#include <SDL/SDL.H>
#include <mikmod.h>
#include <unistd.h>
#include "precalcs.h"
#include "gp32_functions.h"
#include "script.h"
#undef main

int clockspeed = 66;

unsigned char *framebuffer[2];
GPDRAWSURFACE GP32Surface[2];

int flip=0;
int vsync=0;

extern int quit;
extern int partime;

extern int scale;
extern int fullscreen;

MODULE *module;


static void ClearScreen(int page, int c)
{
	unsigned short *vram = (unsigned short*)framebuffer[page];
	int i;

	for (i=0; i<LCD_WIDTH*LCD_HEIGHT; i++)
		*vram++=c;
}


void InitGraphics(int depth)
{
	GpGraphicModeSet(depth, 0);

	GpLcdSurfaceGet(&GP32Surface[0], 0);
	GpLcdSurfaceGet(&GP32Surface[1], 1);

	framebuffer[0] = (unsigned short*)GP32Surface[0].ptbuffer;
	framebuffer[1] = (unsigned short*)GP32Surface[1].ptbuffer;
}


static void InitMusic()
{
	MikMod_RegisterAllDrivers();
    MikMod_RegisterAllLoaders();
	md_mode |= DMODE_SOFT_MUSIC;
	MikMod_Init("");
    module = Player_Load("retroattivo.mod", 64, 0);
    if (module) {
        Player_Start(module);
        }
}


static void Init()
{
    InitSDL();
	InitGraphics(16);

	ClearScreen(0, 0x80a0);
	ClearScreen(1, 0x80a0);

    InitFonts();
	precalcs();

	ClearScreen(0, 0);
	ClearScreen(1, 0);

	InitMusic();
    partime = Ticks();	
}

void exit2menu()
{
	chdir("/usr/gp2x");
	execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL);
}


int main(int argc, char *argv[])
{
    scale = 0;
    vsync = 0;

	Init();
    
	while (!quit)
	{
		Run();
        if (Player_Active())
            MikMod_Update();
        GpSurfaceFlip(&GP32Surface[flip], vsync);
        if (Player_Active())
            MikMod_Update();        
		flip=(flip+1)&1;
	}
    Player_Stop();
    Player_Free(module);
    MikMod_Exit();
    exit2menu();
}
